#version 330

/** Input variable (the position, which is vertex attribute 0) */
layout(location = 0) in vec4 vertex_position;

/** Input variable (the normal, which is vertex attribute 1) (NOT USED HERE) */
layout(location = 1) in vec4 vertex_normal;

/** Input variable (the color, which is vertex attribute 2) */
layout(location = 2) in vec4 vertex_color;

/** Input variable (the uv, which is vertex attribute 3) (NOT USED HERE) */
layout(location = 3) in vec4 vertex_texCoord;

/**
 * Output variable in which we write the rgb color. This
 * variable is forwarded to the fragment shader.
 */
out vec4 color_from_vs;

/**
 * Contains the elapsed time in seconds since the program
 * was started.
 */
uniform float time;

/**
 * Returns a matrix which performs a rotation depending on
 * the time (How this works is not important at the current
 * time, it just allows to rotate the tetrahedron over time
 * so that you can see all faces).
 */
mat4 magicRotation()
{
    return mat4(
        cos(time), 0, -sin(time), 0,
        sin(time)*sin(time*0.81), cos(time*0.81), cos(time)*sin(time*0.81), 0,
        sin(time)*cos(time*0.81), -sin(time*0.81), cos(time)*cos(time*0.81), 0,
        0,0,0,1
    );
}

/**
 * The main function of the vertex shader, which is executed
 * for every vertex.
 */
void main()
{
    // *TODO* (Exercise 1): Convert this color using the
    // algorithms in the assignment sheet:
    color_from_vs = vertex_color;

    // gl_Position is a predefined variable in every vertex
    // shader which has to get a value. We multiply the
    // magicRotation matrix with the vertex position so that
    // the tetrahedron is rotated over time:
    gl_Position =  magicRotation() * vertex_position;
}
